######################################################################
## load the qtlcmst library
######################################################################
source("cmst_R_functions.R") ## change it after we get the package.


######################################################################
## Simulate cross where pheno y1 causally affects phenos y2 and y3
######################################################################
set.seed(987654321)
Cross <- SimCrossCausal(n.ind = 100, 
                        len = rep(100, 3),
                        n.mar = 101,
                        beta = rep(0.5, 2), 
                        add.eff = 1, 
                        dom.eff = 0, 
                        sig2.1 = 0.4, 
                        sig2.2 = 0.1, 
                        eq.spacing = FALSE, 
                        cross.type = "bc", 
                        normalize = TRUE)


######################################################################
## Compute conditional genotype probabilities.
## Perform QTL mapping with H-K regression.
## Plot LOD profiles.
######################################################################
Cross <- calc.genoprob(Cross, step = 1)
Scan <- scanone(Cross, pheno.col = 1:3, method = "hk")
plot(Scan, lodcolumn = 1:3, ylab = "LOD")


######################################################################
## Summarize results by pheno.
######################################################################
summary(Scan[, c(1, 2, 3)], thr = 3)
summary(Scan[, c(1, 2, 4)], thr = 3)
summary(Scan[, c(1, 2, 5)], thr = 3)


######################################################################
## Get causal anchor via joint QTL mapping
######################################################################
commqtls <- GetCommonQtls(Cross, 
                          pheno1 = "y1", 
                          pheno2 = "y3",
                          thr = 3,
                          peak.dist = 5,
                          addcov1 = NULL, 
                          addcov2 = NULL, 
                          intcov1 = NULL, 
                          intcov2 = NULL)
commqtls

######################################################################
## Fit CMST tests
######################################################################
nms <- names(Cross$pheno)
out1 <- CMSTtests(Cross, 
                  pheno1 = nms[1], 
                  pheno2 = nms[2],
                  Q.chr = 1,
                  Q.pos = 55,
                  addcov1 = NULL, 
                  addcov2 = NULL, 
                  intcov1 = NULL, 
                  intcov2 = NULL, 
                  cross.type = "bc",
                  method = "all",
                  penalty = "both")

######################################################################
## Look at the outputs.
######################################################################
out1[1:6]
out1[7]
out1[8:12]
out1[13:17]


######################################################################
## Fit CMST tests from one pheno against multiple ones
######################################################################
out2 <- CMSTtestsList(Cross, 
                      pheno1 = nms[1], 
                      phenos = nms[-1],
                      Q.chr = 1,
                      Q.pos = 55,
                      addcov1 = NULL, 
                      addcov2 = NULL, 
                      intcov1 = NULL, 
                      intcov2 = NULL, 
                      cross.type = "bc",
                      method = "par",
                      penalty = "bic")
out2


